# <a href="https://www.vocaltractlab.de/"><img alt="VocalTractLab" src="/VocalTractLab/logo/VocalTractLabPythonLogo.svg" height="90"></a>

### Warning
This software is currently in alpha stage. You may encounter bugs and future updates may not be backwards-compatible.

# Installation

    pip install vocaltractlab

# Description
A python module that implements the articulatory synthesizer VocalTractLab.